// Declarative approach to define build variants and their UI

let TargetPlatform = {
   name: 'Target platform',
   alternatives: [
     { name: 'Linux',              script: 'targetPlatform.js', args: ['Linux'],       description: 'Build for Linux with GCC compiler' },
	 { name: 'Win64 MinGW',        script: 'targetPlatform.js', args: ['Win64_MinGW'], description: 'Build for Windows 64bit with MinGW GCC', defaultValue: true },
     { name: 'Win64 VisualStudio', script: 'targetPlatform.js', args: ['Win64_MSVS'],  description: 'Build for Windows 64bit with Microsoft Visual Studio Compiler' }
   ]
}

let TargetConfig = {
	name: 'Target configuration',
	alternatives: [
	  { name: 'Debug',   script: 'targetConfig.js', args: ['Debug'],   description: 'Build for Debug' },
	  { name: 'Release', script: 'targetConfig.js', args: ['Release'], description: 'Build for Release', defaultValue: true }
	]
}
  
let DebugPrint = {
   name: 'Debug print',
   script: 'debugPrint.js',
   description: 'Build generated code with additional debug printing',
   defaultValue : false
};

let sourceOptimization = {
	name: 'Sources optimization',
	alternatives: [
	  { name: 'ON',  script: 'optSources.js', args: ['ON'],  description: 'Turn ON sources optimization', defaultValue: true },
	  { name: 'OFF', script: 'optSources.js', args: ['OFF'], description: 'Turn OFF sources optimization' }
	]
};

let ValidateTCs = {
	name: 'Validate TCs',
	script: 'validateTCs.js',
	description: 'Validate settings in TC files to follow team naming policies',
	defaultValue: false
}

let Info = {
	name: 'Print TC info',
	description: 'Print information about basic settings for a TC',
	script: 'printInfo.js',
	defaultValue : false
}

let CommonUtils = {
	name: 'My Utils',
	script: 'myUtils.js',
	description: 'Common utility set'
}

function initBuildVariants(tc) {
  BVF.addCommonUtils(CommonUtils);

  BVF.add(TargetPlatform);
  BVF.add(TargetConfig);
  BVF.add(DebugPrint);
  BVF.add(sourceOptimization);
  BVF.add(ValidateTCs);
  BVF.add(Info);
  
  if (tc.type == CppTransformType.Executable) {
  } else {
  }
  
}
